summaryrefslogtreecommitdiffstats
path: root/src/loggerengine.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/loggerengine.h')
-rw-r--r--src/loggerengine.h74
1 files changed, 43 insertions, 31 deletions
diff --git a/src/loggerengine.h b/src/loggerengine.h
index 9c3ab96..1dfae4e 100644
--- a/src/loggerengine.h
+++ b/src/loggerengine.h
@@ -1,18 +1,18 @@
/*
- # Copyright (c) 2010,2011 - RZ Uni Freiburg
- # Copyright (c) 2010,2011 - OpenSLX Project
- #
- # This program/file is free software distributed under the GPL version 2.
- # See http://openslx.org/COPYING
- #
- # If you have any feedback please consult http://openslx.org/feedback and
- # send your feedback to feedback@openslx.org
- #
- # General information about OpenSLX can be found under http://openslx.org
- #
- #
- # Base for custom logger engines based on QxtLogger libs.
- #
+ * Copyright (c) 2010,2011 - RZ Uni Freiburg
+ * Copyright (c) 2010,2011 - OpenSLX Project
+ *
+ * This program/file is free software distributed under the GPL version 2.
+ * See http://openslx.org/COPYING
+ *
+ * If you have any feedback please consult http://openslx.org/feedback and
+ * send your feedback to feedback@openslx.org
+ *
+ * General information about OpenSLX can be found under http://openslx.org
+ *
+ *
+ * Base for custom logger engines based on QxtLogger libs.
+ *
*/
#ifndef LOGGERENGINE_H_
#define LOGGERENGINE_H_
@@ -20,25 +20,25 @@
#include <QxtCore>
#include <QTime>
#include <QTextEdit>
+
//---------------------------------------------------------------------------------------------------
// base of a custom logger engine for the framebuffer
//---------------------------------------------------------------------------------------------------
class LoggerEngine_fb: public QxtLoggerEngine {
public:
- LoggerEngine_fb(QTextEdit* parent);
- ~LoggerEngine_fb();
+ LoggerEngine_fb(QTextEdit* parent);
+ ~LoggerEngine_fb();
- // parent widget, target of messages
- QTextEdit *_debugConsole;
- bool _initialized;
+ // parent widget, target of messages
+ QTextEdit *_debugConsole;
+ bool _initialized;
- // reimplemented virtual functions of QxtLoggerEngine
- void initLoggerEngine();
- void killLoggerEngine();
- void writeFormatted(QxtLogger::LogLevel level,
- const QList<QVariant> & messages);
- void setLogLevelEnabled(QxtLogger::LogLevels level, bool enable = true);
- bool isInitialized() const;
+ // reimplemented virtual functions of QxtLoggerEngine
+ void initLoggerEngine();
+ void killLoggerEngine();
+ void writeFormatted(QxtLogger::LogLevel level, const QList<QVariant> & messages);
+ void setLogLevelEnabled(QxtLogger::LogLevels level, bool enable = true);
+ bool isInitialized() const;
};
//---------------------------------------------------------------------------------------------------
@@ -46,12 +46,24 @@ public:
//---------------------------------------------------------------------------------------------------
class LoggerEngine_std: public QxtBasicSTDLoggerEngine {
public:
- LoggerEngine_std();
- ~LoggerEngine_std();
+ LoggerEngine_std();
+ ~LoggerEngine_std();
+
+ // reimplemented virtual functions of QxtBasicSTDLoggerEngine
+ void writeToStdOut(const QString& level, const QList<QVariant> &msgs);
+ void writeToStdErr(const QString& str_level, const QList<QVariant> &msgs);
+};
+//---------------------------------------------------------------------------------------------------
+// slighty modified QxtBasicFileLoggerEngine
+//---------------------------------------------------------------------------------------------------
+class LoggerEngine_file: public QxtBasicFileLoggerEngine {
+public:
+ LoggerEngine_file(const QString& logFileName);
+ ~LoggerEngine_file();
+ void initLoggerEngine();
- // reimplemented virtual functions of QxtBasicSTDLoggerEngineqqq
- void writeToStdOut(const QString& level, const QList<QVariant> &msgs);
- void writeToStdErr(const QString& str_level, const QList<QVariant> &msgs);
+ // reimplemented virtual functions of QxtBasicFileLoggerEngine
+ void writeToFile(const QString& level, const QList<QVariant> &msgs);
};
#endif // LOGGERENGINE_H_